Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/FastLED/FastLED.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/colorutils.cpp4
-rw-r--r--src/colorutils.h20
2 files changed, 12 insertions, 12 deletions
diff --git a/src/colorutils.cpp b/src/colorutils.cpp
index d1f45bd9..18aa9ed8 100644
--- a/src/colorutils.cpp
+++ b/src/colorutils.cpp
@@ -62,7 +62,7 @@ void fill_rainbow( struct CHSV * targetArray, int numToFill,
}
-void fill_rainbow_endless(struct CRGB* targetArray, int numToFill, uint8_t initialhue)
+void fill_rainbow_circular(struct CRGB* targetArray, int numToFill, uint8_t initialhue)
{
if (numToFill == 0) return; // avoiding div/0
@@ -81,7 +81,7 @@ void fill_rainbow_endless(struct CRGB* targetArray, int numToFill, uint8_t initi
}
}
-void fill_rainbow_endless(struct CHSV* targetArray, int numToFill, uint8_t initialhue)
+void fill_rainbow_circular(struct CHSV* targetArray, int numToFill, uint8_t initialhue)
{
if (numToFill == 0) return; // avoiding div/0
diff --git a/src/colorutils.h b/src/colorutils.h
index 237e9400..d33ce55e 100644
--- a/src/colorutils.h
+++ b/src/colorutils.h
@@ -37,18 +37,18 @@ void fill_rainbow( struct CHSV * targetArray, int numToFill,
uint8_t deltahue = 5);
-/// fill_rainbow_endless - fill a range of LEDs with a rainbow of colors, at
-/// full saturation and full value (brightness),
-/// so that the hues are continuous between the end
-/// of the strip and the beginning
-void fill_rainbow_endless(struct CRGB* targetArray, int numToFill,
+/// fill_rainbow_circular - fill a range of LEDs with a rainbow of colors, at
+/// full saturation and full value (brightness),
+/// so that the hues are continuous between the end
+/// of the strip and the beginning
+void fill_rainbow_circular(struct CRGB* targetArray, int numToFill,
uint8_t initialhue);
-/// fill_rainbow_endless - fill a range of LEDs with a rainbow of colors, at
-/// full saturation and full value (brightness),
-/// so that the hues are continuous between the end
-/// of the strip and the beginning
-void fill_rainbow_endless(struct CHSV* targetArray, int numToFill,
+/// fill_rainbow_circular - fill a range of LEDs with a rainbow of colors, at
+/// full saturation and full value (brightness),
+/// so that the hues are continuous between the end
+/// of the strip and the beginning
+void fill_rainbow_circular(struct CHSV* targetArray, int numToFill,
uint8_t initialhue);